@@ -4,24 +4,26 @@ Just useful objects to make your coding nicer every day
 
 from .algos import merge_dicts
 from .concurrent import Monitor, RMonitor
-from .decorators import precondition, for_argument, PreconditionError, short_none, has_keys, \
-    attach_arguments, wraps, chain_functions, auto_adapt_to_methods, postcondition, queue_get
-from .fun_static import static_var
-from .metaclasses import metaclass_maker, wrap_with, dont_wrap, wrap_property
-from .recast_exceptions import rethrow_as, silence_excs, catch_exception, log_exceptions, raises_exception
-from .iterators import hint_with_length, SelfClosingGenerator, exhaust, chain
+from .decorators import precondition, short_none, has_keys, \
+    wraps, chain_functions, postcondition, queue_get, auto_adapt_to_methods, \
+    attach_arguments, for_argument
 from .deleters import ListDeleter, DictDeleter
+from .fun_static import static_var
+from .iterators import hint_with_length, SelfClosingGenerator, exhaust, chain
+from .metaclasses import metaclass_maker, wrap_with, dont_wrap, wrap_property
 from .misc import update_if_not_none
+from .recast_exceptions import rethrow_as, silence_excs, catch_exception, log_exceptions, \
+    raises_exception
 
 __all__ = [
     'update_if_not_none',
     'hint_with_length', 'SelfClosingGenerator', 'exhaust', 'chain',
     'Monitor', 'RMonitor', 'merge_dicts',
-    'for_argument', 'short_none', 'has_keys',
-    'precondition', 'PreconditionError', 'attach_arguments', 'postcondition', 'queue_get',
+    'short_none', 'has_keys',
+    'precondition', 'postcondition', 'queue_get',
     'rethrow_as', 'silence_excs', 'raises_exception',
     'static_var', 'metaclass_maker',
-    'catch_exception', 'wraps', 'wrap_with', 'dont_wrap', 'wrap_property', 'log_exceptions', 'chain_functions',
-    'auto_adapt_to_methods',
-    'ListDeleter', 'DictDeleter'
+    'catch_exception', 'wraps', 'wrap_with', 'dont_wrap', 'wrap_property', 'log_exceptions',
+    'chain_functions',
+    'ListDeleter', 'DictDeleter', 'for_argument', 'attach_arguments', 'auto_adapt_to_methods',
 ]
