@@ -3,8 +3,9 @@ from .callablegroup import CallableGroup, CallNoOftenThan
 from .locked_dataset import LockedDataset
 from .locked_structure import LockedStructure
 from .monitor import MonitorList, Monitor, MonitorDict, RMonitor
-from .thread import TerminableThread, Condition
+from .thread import TerminableThread, Condition, SingleStartThread
+from .id_allocator import IDAllocator
 
 __all__ = ['LockedDataset', 'Monitor', 'RMonitor', 'CallableGroup', 'TerminableThread',
            'MonitorDict', 'MonitorList', 'Condition', 'LockedStructure', 'AtomicNumber',
-           'CallNoOftenThan']
+           'CallNoOftenThan', 'SingleStartThread', 'IDAllocator']
