@@ -1,9 +1,9 @@
 import inspect
-import typing as tp
 import logging
 import threading
-from .decorators import wraps
+import typing as tp
 
+from .decorators import wraps
 
 ExcType = tp.Type[Exception]
 T = tp.TypeVar('T')
@@ -38,8 +38,10 @@ class log_exceptions:
     :param severity: a severity level
     :param format_string: a format string with fields:
         - e      : the exception instance itself
-        - args   : positional arguments with which the function was called, unavailable if context manager
-        - kwargs : keyword arguments with which the function was called, unavailable if context manager
+        - args   : positional arguments with which the function was called, unavailable if context
+                   manager
+        - kwargs : keyword arguments with which the function was called, unavailable if context
+                   manager
         You can specify additional fields providing the locals_ argument
         Example: "{exc_type} occurred with message {exc_val} with traceback {exc_tb}"
     :param locals_: local variables to add to the format string. args and kwargs will be overwritten
@@ -91,6 +93,7 @@ class log_exceptions:
                     yield from fun(*args, **kwargs)
                 except Exception as e:
                     self.analyze_exception(e, args, kwargs)
+
             return inner
         else:
             @wraps(fun)
@@ -99,6 +102,7 @@ class log_exceptions:
                     return fun(*args, **kwargs)
                 except Exception as e:
                     self.analyze_exception(e, args, kwargs)
+
             return inner
 
 
