@@ -31,7 +31,7 @@ def is_last(lst: tp.Iterable[T]) -> tp.Generator[tp.Tuple[bool, T], None, None]:
 
 
 def add_next(lst: tp.Iterable[T], wrap_over: bool = False, skip_last: bool = False) -> tp.Iterator[
-        tp.Tuple[T, tp.Optional[T]]]:
+    tp.Tuple[T, tp.Optional[T]]]:
     """
     Yields a 2-tuple of given iterable, presenting the next element as second element of the tuple.
 
@@ -63,7 +63,8 @@ def add_next(lst: tp.Iterable[T], wrap_over: bool = False, skip_last: bool = Fal
             yield prev_val, None
 
 
-def half_cartesian(seq1: tp.Iterable[T], include_same_pairs: bool = True) -> tp.Iterator[tp.Tuple[T, T]]:
+def half_cartesian(seq1: tp.Iterable[T], include_same_pairs: bool = True) -> tp.Iterator[
+    tp.Tuple[T, T]]:
     """
     Generate half of the Cartesian product of both sequences.
 
