@@ -5,7 +5,7 @@ from .hashable_objects import HashableWrapper
 from .heaps import Heap, SetHeap, TimeBasedHeap, TimeBasedSetHeap
 from .immutable import Immutable, frozendict
 from .mixins import OmniHashableMixin, ReprableMixin, StrEqHashableMixin, ComparableIntEnum, \
-    HashableIntEnum
+    HashableIntEnum, ComparableAndHashableBy
 from .proxy import Proxy
 from .ranking import Ranking
 from .singleton import Singleton, SingletonWithRegardsTo
@@ -19,6 +19,7 @@ __all__ = [
     'ReprableMixin',
     'StrEqHashableMixin',
     'ComparableIntEnum',
+    'ComparableAndHashableBy',
     'HashableIntEnum',
     'DirtyDict',
     'SortedList',
