@@ -1,4 +1,3 @@
-import collections
 import threading
 import time
 import typing as tp
@@ -60,7 +59,7 @@ class ExpiringEntryDictThread(threading.Thread, Monitor):
         self.start()
 
 
-class SelfCleaningDefaultDict(Monitor, collections.UserDict, tp.Generic[K, V], Cleanupable):
+class SelfCleaningDefaultDict(Monitor, tp.MutableMapping[K, V], Cleanupable):
     """
     A defaultdict with the property that if it detects that a value is equal to it's default value,
     it will automatically remove it from the dict.
@@ -72,15 +71,32 @@ class SelfCleaningDefaultDict(Monitor, collections.UserDict, tp.Generic[K, V], C
     It is preferable to :meth:`satella.coding.concurrent.Monitor.acquire` it before iterating, since
     it is cleaned up both by __iter__ and by an external worker thread, so it's important to acquire
     it, because it can mutate in an undefined way.
+
+    Note that if you access a key which does not exist, and background_maintenance is False,
+    a default value will be created and inserted into the dictionary. This is the only
+    time that the dictionary will hold values that are equal to default.
+
+    :param default_factory: a callable/0 that will return an object if it doesn't already exist
+    :param background_maintenance: whether to spawn a background thread. This is required
+        if dictionary values can change their value between inserts.
+
+    All args and kwargs will be passed to a dict, which will be promptly added to this dictionary.
     """
 
-    def __init__(self, default_factory: tp.Callable[[], V], *args, **kwargs):
-        super().__init__()
-        collections.UserDict.__init__(self, *args, **kwargs)
+    def __len__(self) -> int:
+        self.cleanup()
+        return len(self.data)
+
+    def __init__(self, default_factory: tp.Callable[[], V],
+                 background_maintenance: bool = True, *args, **kwargs):
+        super().__init__()  # initialize the inner Monitor
+        self.data = dict(*args, **kwargs)
         self.default_factory = default_factory
         self.default_value = default_factory()
 
-        ExpiringEntryDictThread().add_dict(self)
+        self.background_maintenance = background_maintenance
+        if self.background_maintenance:
+            ExpiringEntryDictThread().add_dict(self)
 
     def __iter__(self) -> tp.Iterator[K]:
         self.cleanup()
@@ -90,16 +106,28 @@ class SelfCleaningDefaultDict(Monitor, collections.UserDict, tp.Generic[K, V], C
         if key in self.data:
             del self.data[key]
 
+    @Monitor.synchronized
     def __getitem__(self, item: K) -> V:
-        if item not in self.data:
-            self.data[item] = self.default_factory()
-        return self.data[item]
+        try:
+            v = self.data[item]
+            if v == self.default_value:
+                del self.data[item]
+            return v
+        except KeyError:
+            obj = self.default_factory()
+            if not self.background_maintenance:
+                self.data[item] = obj
+            return obj
 
+    @Monitor.synchronized
     def __setitem__(self, key: K, value: V) -> None:
+        value_equal = value == self.default_value
         if key in self.data:
-            if value == self.default_value:
+            if value_equal:
                 del self.data[key]
-        self.data[key] = value
+
+        if not value_equal:
+            self.data[key] = value
 
     @Monitor.synchronized
     @silence_excs(KeyError)  # because entries may disappear without warning
@@ -109,7 +137,7 @@ class SelfCleaningDefaultDict(Monitor, collections.UserDict, tp.Generic[K, V], C
                 del self.data[key]
 
 
-class ExpiringEntryDict(Monitor, collections.UserDict, tp.Generic[K, V], Cleanupable):
+class ExpiringEntryDict(Monitor, tp.MutableMapping[K, V], Cleanupable):
     """
     A dictionary whose entries expire automatically after a predefined period of time.
 
@@ -124,12 +152,19 @@ class ExpiringEntryDict(Monitor, collections.UserDict, tp.Generic[K, V], Cleanup
     :param external_cleanup: whether to spawn a single thread that will clean up the dictionary.
         The thread is spawned once per program, and no additional threads are spawned for next
         dictionaries.
+
+    All args and kwargs will be passed to a dict, which will be promptly added to this dictionary.
     """
 
+    def __len__(self) -> int:
+        self.cleanup()
+        return len(self.data)
+
     def __init__(self, expiration_timeout: float, *args,
                  time_getter: tp.Callable[[], float] = time.monotonic,
                  external_cleanup: bool = False, **kwargs):
-        super().__init__()
+        super().__init__()  # initialize the inner Monitor
+        self.data = dict()
         self.expire_on = {}
         self.time_getter = time_getter
         self.expiration_timeout = expiration_timeout
@@ -138,7 +173,9 @@ class ExpiringEntryDict(Monitor, collections.UserDict, tp.Generic[K, V], Cleanup
         if external_cleanup:
             ExpiringEntryDictThread().add_dict(self)
 
-        collections.UserDict.__init__(self, *args, **kwargs)
+        dct = dict(*args, **kwargs)
+        for key, value in dct.items():
+            self[key] = value
 
     def __contains__(self, item) -> bool:
         try:
@@ -170,19 +207,21 @@ class ExpiringEntryDict(Monitor, collections.UserDict, tp.Generic[K, V], Cleanup
         for ts, key in self.key_to_expiration_time.pop_less_than(self.time_getter()):
             del self.data[key]
 
+    @Monitor.synchronized
     def __setitem__(self, key: K, value: V) -> None:
         self.key_to_expiration_time.put(self.time_getter() + self.expiration_timeout, key)
-        super().__setitem__(key, value)
+        self.data[key] = value
 
     @rethrow_as(ValueError, KeyError)
     def __getitem__(self, item: K) -> V:
         ts = self.key_to_expiration_time.get_timestamp(item)
         if ts < self.time_getter():
-            del self[item]
+            del self.data[item]
             raise KeyError('Entry expired')
 
-        return super().__getitem__(item)
+        return self.data[item]
 
+    @Monitor.synchronized
     def __delitem__(self, key: K) -> None:
         self.key_to_expiration_time.pop_item(key)
-        super().__delitem__(key)
+        del self.data[key]
