@@ -1,21 +1,31 @@
-import collections.abc
 import copy
 import typing as tp
 
 K, V, T = tp.TypeVar('K'), tp.TypeVar('V'), tp.TypeVar('T')
 
 
-class DirtyDict(collections.UserDict, tp.Generic[K, V]):
+class DirtyDict(tp.MutableMapping[K, V]):
     """
     A dictionary that has also a flag called .dirty that sets to True if the dictionary has been
     changed since that flag was last cleared.
 
     Setting the dict with the value that it already has doesn't count as dirtying it.
     Note that such changes will not be registered in the dict!
+
+    All arguments and kwargs will be passed to dict's constructor.
     """
 
+    def __len__(self) -> int:
+        return len(self.data)
+
+    def __iter__(self) -> tp.Iterator[K]:
+        return iter(self.data)
+
+    def __getitem__(self, k: K) -> V:
+        return self.data[k]
+
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+        self.data = dict(*args, **kwargs)  # type: tp.Dict[K, V]
         self.dirty = False
 
     def __copy__(self) -> 'DirtyDict':
@@ -24,16 +34,19 @@ class DirtyDict(collections.UserDict, tp.Generic[K, V]):
         return dd
 
     def __setitem__(self, key: K, value: V) -> None:
-        if key in self:
-            if self[key] == value:
+        if key in self.data:
+            if self.data[key] == value:
                 return
-        super().__setitem__(key, value)
+        self.data[key] = value
         self.dirty = True
 
     def __delitem__(self, key: K) -> None:
-        super().__delitem__(key)
+        del self.data[key]
         self.dirty = True
 
+    def __contains__(self, item: K) -> bool:
+        return item in self.data
+
     def clear_dirty(self) -> None:
         """Clears the dirty flag"""
         self.dirty = False
@@ -65,7 +78,7 @@ class DirtyDict(collections.UserDict, tp.Generic[K, V]):
         return a
 
 
-class KeyAwareDefaultDict(collections.abc.MutableMapping):
+class KeyAwareDefaultDict(tp.MutableMapping[K, V]):
     """
     A defaultdict whose factory function accepts the key to provide a default value for the key
 
@@ -97,7 +110,7 @@ class KeyAwareDefaultDict(collections.abc.MutableMapping):
         del self.dict[key]
 
 
-class TwoWayDictionary(collections.abc.MutableMapping, tp.Generic[K, V]):
+class TwoWayDictionary(tp.MutableMapping[K, V]):
     """
     A dictionary that keeps also a reverse_data mapping, allowing to look up keys by values.
 
@@ -188,7 +201,7 @@ class TwoWayDictionary(collections.abc.MutableMapping, tp.Generic[K, V]):
         return self._reverse
 
 
-class DictionaryView(collections.abc.MutableMapping, tp.Generic[K, V]):
+class DictionaryView(tp.MutableMapping[K, V]):
     """
     A view on a multiple dictionaries. If key isn't found in the first dictionary, it is looked up
     in another. Use like:
