@@ -1,6 +1,4 @@
 import enum
-import functools
-import operator
 import typing as tp
 from abc import ABCMeta, abstractmethod
 
@@ -58,6 +56,49 @@ class StrEqHashableMixin(metaclass=ABCMeta):
         pass
 
 
+class ComparableAndHashableBy(metaclass=ABCMeta):
+    """
+    A mix-in. Provides comparision (lt, gt, ge, le, eq) and hashing by a field of this class.
+
+    Example:
+
+    >>> class Vector(ComparableAndHashableBy):
+    >>>     _COMPARABLE_BY = 'length'
+    >>>     @property
+    >>>     def length(self):
+    >>>         ...
+    >>>
+    >>> assert Vector() > Vector()
+    """
+
+    @property
+    @abstractmethod
+    def _COMPARABLE_BY(self) -> str:
+        """
+        Return the sequence of names of properties and attributes
+        that will be used for __eq__ and __hash__
+        """
+        return ''
+
+    def __hash__(self):
+        return hash(getattr(self, self._COMPARABLE_BY))
+
+    def __eq__(self, other: 'ComparableAndHashableBy') -> bool:
+        return getattr(self, self._COMPARABLE_BY) == getattr(other, other._COMPARABLE_BY)
+
+    def __lt__(self, other: 'ComparableAndHashableBy') -> bool:
+        return getattr(self, self._COMPARABLE_BY) < getattr(other, other._COMPARABLE_BY)
+
+    def __le__(self, other: 'ComparableAndHashableBy') -> bool:
+        return getattr(self, self._COMPARABLE_BY) <= getattr(other, other._COMPARABLE_BY)
+
+    def __gt__(self, other: 'ComparableAndHashableBy') -> bool:
+        return getattr(self, self._COMPARABLE_BY) > getattr(other, other._COMPARABLE_BY)
+
+    def __ge__(self, other: 'ComparableAndHashableBy') -> bool:
+        return getattr(self, self._COMPARABLE_BY) >= getattr(other, other._COMPARABLE_BY)
+
+
 class OmniHashableMixin(metaclass=ABCMeta):
     """
     A mix-in. Provides hashing and equal comparison for your own class using specified fields.
@@ -65,7 +106,7 @@ class OmniHashableMixin(metaclass=ABCMeta):
     Example of use:
 
     >>> class Point2D(OmniHashableMixin):
-    >>>    _HASH_FIELDS_TO_USE = ['x', 'y']
+    >>>    _HASH_FIELDS_TO_USE = ('x', 'y')
     >>>    def __init__(self, x, y):
     >>>        ...
 
@@ -73,6 +114,9 @@ class OmniHashableMixin(metaclass=ABCMeta):
     Do everything in your power to make specified fields immutable, as mutating them will result
     in a different hash.
 
+    _HASH_FIELDS_TO_USE can be also a single string, in this case a single field called by this
+    name will be taken.
+
     Note that if you're explicitly providing __eq__ in your child class, you will be required to
     insert:
 
@@ -84,36 +128,53 @@ class OmniHashableMixin(metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def _HASH_FIELDS_TO_USE(self) -> tp.Sequence[str]:
+    def _HASH_FIELDS_TO_USE(self) -> tp.Tuple[str]:
         """
         Return the sequence of names of properties and attributes
         that will be used for __eq__ and __hash__
         """
         return ()
 
-    def __hash__(self):
-        return functools.reduce(operator.xor, (hash(getattr(self, field_name))
-                                               for field_name in self._HASH_FIELDS_TO_USE))
+    def __hash__(self) -> int:
+        xor = 0
+        cmpr_by = self._HASH_FIELDS_TO_USE
+        if isinstance(cmpr_by, str):
+            return hash(getattr(self, cmpr_by))
 
-    def __eq__(self, other: 'OmniHashableMixin') -> bool:
+        for field_name in cmpr_by:
+            xor ^= hash(getattr(self, field_name))
+        return xor
+
+    def __eq__(self, other) -> bool:
         """
         Note that this will only compare _HASH_FIELDS_TO_USE
         """
-
-        def con(p):
-            return tuple(getattr(p, field_name) for field_name in self._HASH_FIELDS_TO_USE)
-
         if isinstance(other, OmniHashableMixin):
-            try:
-                if con(self) == con(other):
-                    return True
-            except AttributeError:
-                return False
+            cmpr_by = self._HASH_FIELDS_TO_USE
+
+            if isinstance(cmpr_by, str):
+                return getattr(self, cmpr_by) == getattr(other, cmpr_by)
+
+            for field_name in self._HASH_FIELDS_TO_USE:
+                if getattr(self, field_name) != getattr(other, field_name):
+                    return False
+            return True
         else:
             return super().__eq__(other)
 
-    def __ne__(self, other: 'OmniHashableMixin') -> bool:
-        return not self.__eq__(other)
+    def __ne__(self, other) -> bool:
+        if isinstance(other, OmniHashableMixin):
+            cmpr_by = self._HASH_FIELDS_TO_USE
+
+            if isinstance(cmpr_by, str):
+                return getattr(self, cmpr_by) != getattr(other, cmpr_by)
+
+            for field_name in cmpr_by:
+                if getattr(self, field_name) != getattr(other, field_name):
+                    return True
+            return False
+        else:
+            return super().__ne__(other)
 
 
 class ReprableMixin:
