@@ -1,6 +1,5 @@
 from __future__ import print_function, absolute_import, division
 
-import logging
 import os
 import typing as tp
 import uuid
@@ -9,8 +8,6 @@ from satella.coding import silence_excs
 from satella.instrumentation import Traceback
 from .exception_handlers import BaseExceptionHandler
 
-logger = logging.getLogger(__name__)
-
 __all__ = [
     'DumpToFileHandler'
 ]
@@ -102,9 +99,9 @@ class DumpToFileHandler(BaseExceptionHandler):
         super(DumpToFileHandler, self).__init__()
         self.hr = [AsStream(x, True)
                    if not isinstance(x, AsStream) else x
-                   for x in human_readables]        # type: tp.List[AsStream]
+                   for x in human_readables]  # type: tp.List[AsStream]
         self.tb = [AsStream(x, False) if not isinstance(x, AsStream) else x for x in
-                   trace_pickles or []]             # type: tp.List[AsStream]
+                   trace_pickles or []]  # type: tp.List[AsStream]
 
     def handle_exception(self, type_, value, traceback) -> bool:
         try:
