@@ -1,5 +1,6 @@
 import types
 import typing as tp
+import warnings
 from abc import abstractmethod
 
 __all__ = [
@@ -21,7 +22,7 @@ ExceptionHandlerCallable = tp.Callable[[type, BaseException, types.TracebackType
 
 
 class BaseExceptionHandler:
-    __slots__ = ('priority', )
+    __slots__ = ('priority',)
 
     def __init__(self, priority=NORMAL_PRIORITY):
         """
@@ -61,9 +62,10 @@ class FunctionExceptionHandler(BaseExceptionHandler):
     """
     A exception handler to make callables of given signature into Satella's exception handlers.
 
-    Your exception handler must return a bool, whether to intercept the exception and not propagate it.
+    Your exception handler must return a bool, whether to intercept the exception and not
+    propagate it.
     """
-    __slots__ = ('fun', )
+    __slots__ = ('fun',)
 
     def __init__(self, fun: ExceptionHandlerCallable, priority: int = NORMAL_PRIORITY):
         super(FunctionExceptionHandler, self).__init__(priority)
@@ -86,11 +88,21 @@ def exception_handler(priority: int = NORMAL_PRIORITY):
     >>> def handle_exc(type_, val, traceback):
     >>>     ...
 
+    You can use also:
+
+    >>> @exception_handler
+    >>> def handle_exc(type_, val, traceback):
+    >>>     ...
+
+    The default priority is 0. But this way of calling it is not recommended, and will
+    result in a UserWarning.
+
     :return: ExceptionHandler instance
     """
 
     if not isinstance(priority, int):
-        raise TypeError('Did you forget to use it as @exception_handler() ?')
+        warnings.warn('Please specify priority, using default of 0', UserWarning)
+        return FunctionExceptionHandler(priority, priority=NORMAL_PRIORITY)
 
     def outer(fun: ExceptionHandlerCallable) -> FunctionExceptionHandler:
         return FunctionExceptionHandler(fun, priority=priority)
